/* Do not edit or override these styles! The system will likely break if you do. */

div#header, div#footer, div.slide {position: absolute;}
html>body div#header, html>body div#footer, html>body div.slide {position: fixed;}
div#header {z-index: 1;}
div.slide  {z-index: 2; visibility: hidden;}
#slide0 {visibility: visible;}
div#footer {z-index: 5;}
div#controls {position: absolute; z-index: 1;}
#footer>div#controls {position: fixed;}
.handout {display: none;}
/* The following styles size and place the slide components.
   Edit them if you want to change the overall slide layout.
   The commented lines can be uncommented (and modified, if necessary) 
    to help you with the rearrangement process. */

div#header, div#footer, div.slide {width: 100%; top: 0; left: 0;}
div#header {top: 0; height: 3em;}
div#footer {top: auto; bottom: 0; height: 2.5em;}
div.slide {top: 0; width: 92%; padding: 3.5em 4% 4%;}
div#controls {left: 50%; top: 0; width: 50%; height: 100%;}
#footer>div#controls {bottom: 0; top: auto; height: auto;}

div#controls form {position: absolute; bottom: 0; right: 0; width: 100%;
  margin: 0;}
#currentSlide {position: absolute; width: 10%; left: 45%; bottom: 1em; z-index: 10;}
html>body #currentSlide {position: fixed;}

/*
div#header {background: #FCC;}
div#footer {background: #CCF;}
div#controls {background: #BBD;}
div#currentSlide {background: #FFC;}
*/
/* Following are the presentation styles -- edit away!
   Note that the 'body' font size may have to be changed if the resolution is
    different than expected. */

body {background: #f3f3f3 url(bodybg.gif); color: #000; font-size: 2em; font-family: Verdana, Arial, sans-serif;}

a {
	color: #c30;
	text-decoration: none;
}

a:hover {
	text-decoration: underline;
}

:link, :visited {text-decoration: none;}
#controls :active {color: #333 !important;}
#controls :focus {outline: none;}
h1, h2, h3, h4 {font-size: 100%; margin: 0; padding: 0; font-weight: inherit;}
ul, pre {margin: 0; line-height: 1em;}
html, body {margin: 0; padding: 0;}

blockquote, q {font-style: italic;}
blockquote {padding: 0 2em 0.5em; margin: 0 1.5em 0.5em; text-align: center; font-size: 1em;}
blockquote p {margin: 0;}
blockquote i {font-style: normal;}
blockquote b {display: block; margin-top: 0.5em; font-weight: normal; font-size: smaller; font-style: normal;}
blockquote b i {font-style: italic;}

kbd {font-weight: bold; font-size: 1em;}
sup {font-size: smaller; line-height: 1px;}

code {padding: 2px 0.25em; font-weight: bold; color: #555;}
code.bad, code del {color: red;}
code.old {color: silver;}
pre {font-size: .7em;
	margin: 0 auto;
	background-color: #f3f3f3;
	border: 1px solid #d5d5d5;
	width: 80%;
	padding: 20px;}
pre code {display: block;}
pre code span {
	font-weight: normal;
	font-size: 0.98em;
}
ul {margin-left: 85px; margin-right: 3%; list-style: disc; padding: 0;}
li {margin-top: 5px; margin-right: 0;}
ul ul {line-height: 1;}
ul ul li {margin: .2em; font-size: 85%; list-style: square;}
p, li {
	line-height: 1.2;
}
img.leader {display: block; margin: 0 auto;}


div#header, div#footer {color: #AAB;
  font-family: Verdana, Helvetica, sans-serif;}
div#header {background: #f3f3f3 url(head.gif) repeat-x top;
  line-height: 1px;}
div#footer {font-size: 0.5em; font-weight: bold; padding: 1em 0; color: #666;}
#footer h1, #footer h2 {display: block; padding: 0 1em;}
#footer h2 {margin-top: 0.5em;}

div.long {font-size: 0.75em;}
.slide h1 {position: absolute; top: 0.8em; left: 0; z-index: 1;
  margin-left: 85px; padding: 0; white-space: nowrap;
  font-weight: bold; font-size: 150%; line-height: 1;
  color: #f3f3f3;}
.slide h3 {font-size: 130%;}
h1 abbr {font-variant: small-caps;}

div#controls {position: absolute; z-index: 5; left: 75%; top: 0;
  width: 25%; height: 100%;
  text-align: right;}
#footer>div#controls {position: fixed; bottom: 0; padding: 2em 0;
  top: auto; height: auto;}
div#controls form {position: absolute; bottom: 0; right: 0; width: 100%;
  margin: 0; padding: 0;}
div#controls a {font-size: 2em; padding: 0; margin: 0 0.2em; border: none; color: #f3f3f3; 
  cursor: pointer;}
div#controls a:hover {color: #f3f3f3;}
div#controls select {visibility: hidden; background: #f3f3f3; color: #333;}
div#controls div:hover select {visibility: visible;}

#toggle, #prev, #next {
	display: block;
	width: 35px; height: 35px;
	line-height: 35px;
	float: left;
	background: url(button.gif) no-repeat 0 0;
}
#toggle {

}
#next {
	text-align: left;
}

#currentSlide {text-align: center; font-size: 0.5em; color: #666; font-weight: bold;}
#currentSlide span {display: none;}

#slide0 {padding-top: 3.5em; font-size: 90%;}
#slide0 h1 {position: static; margin: 1em 0 1.33em; padding: 5px 0 5px 20px;
   font: bold 2.2em Arial, Verdana, sans-serif; white-space: normal;
   color: #000; background: transparent url(slide0h1.gif) no-repeat left bottom;
	text-transform: none; }
#slide0 h3 {margin-top: 0.3em; font-size: 1.2em;}
#slide0 h4 {margin:0; font-size: 0.9em;}

ul.urls {list-style: none; display: inline; margin: 0;}
.urls li {display: inline; margin: 0;}
.note {display: none;}

acronym {
	font-size: 90%;
}

div.image {
	margin: 0 auto;
	text-align: center;
	background-color: #f3f3f3;
	border: 1px solid #000;
	font-size: 0.66%;
	width: 400px;
	padding: 20px;
}

p { 
	margin-left: 85px;
}

div.image p, #slide0 p {
	margin-left: 0;
}