/* Do not edit or override these styles! The system will likely break if you do. */

div#header, div#footer, div.slide {position: absolute;}
html>body div#header, html>body div#footer, html>body div.slide {position: fixed;}
div.slide {visibility: hidden;}
#slide0 {visibility: visible;}
div#controls {position: absolute;}
#footer>div#controls {position: fixed;}
.handout {display: none;}
/* The following styles size and place the slide components.
   Edit them if you want to change the overall slide layout.
   The commented lines can be uncommented (and modified, if necessary) 
    to help you with the rearrangement process. */

div#header, div#footer, div.slide {width: 100%; top: 0; left: 0;}
div#header {top: 0; left: 0; z-index: 1;}
div#footer {top: auto; bottom: 0; width: 100%; z-index: 5;}
div.slide {top: 0; width: 88%; padding: 1em 7% 2em 5%; z-index: 2;}

#footer div#controls {bottom: 1.5em; left: 0; width: 100%; text-align: center; z-index: 1;}
div#controls form {margin: 0; padding: 0;}

#currentSlide {position: absolute; left: 0; bottom: 0.5em; z-index: 10;
  width: 100%; text-align: center;}
html>body #currentSlide {position: fixed;}

/*
div#header {background: #FCC;}
div#footer {background: #CCF;}
div#controls {background: #BBD;}
div#currentSlide {background: #FFC;}
*/
/* Following are the presentation styles -- edit away!
   Note that the 'body' font size may have to be changed if the resolution is
    different than expected. */

body {background: #95A7D4 url(bg-slide.jpg) 100% 100% no-repeat; color: #210; font: 29px Arial, sans-serif;}
a {text-decoration: none; color: #336; border-bottom: 1px dotted;}
h1, h2, h3, h4, h5, h6 {font-size: 1em; margin: 0;}
sup {font-size: 0.75em; font-weight: normal;
  vertical-align: 0.5em; line-height: 1px;}
ul {margin-left: 1em; padding-left: 0;}
li {margin-bottom: 0.66em;}
li li {margin: 0.33em 0; font-size: smaller;}

#header {background: url(bg-shade.png); border-bottom: 1px solid #333;
  padding-bottom: 2em;}
#footer {background: url(bg-shade.png); color: #BBB; border-top: 1px solid #333;}
#header, #footer {font-size: 0.5em;}
#footer h1, #footer h2 { padding: 0.5em 0.75em;
  font-weight: normal; font-style: italic;}
#footer h1 {left: 0; font-size: 1em; letter-spacing: 1px;}
#footer h2 {position: absolute; bottom: 0; right: 0;}

#controls a {display: none;}
#controls select {visibility: hidden;}
#controls div:hover select {visibility: visible;}

#currentSlide {font-size: 0.5em;}
#currentSlide span {font-size: 13px; color: rgb(49%,47%,66%);}
#currentSlide #csSep {display: none;}
#currentSlide #csHere {font-weight: bold;}
#currentSlide #csHere:before {content: "#"; font-weight: normal;}
#currentSlide #csTotal:before {content: " of ";}

.slide h1 {font-size: 1.66em; line-height: 1; letter-spacing: -1px;
  margin: 0 -15% 1em 0; padding: 0.25em 15% 0.06125em 0; border-bottom: 0.06125em solid rgb(90,94,120);}
#slide0 h1 {border: none; font-size: 2.25em; letter-spacing: 0; margin: 3em 0 1.5em;}
#slide0 h3 {margin-bottom: 0;}
#slide0 h4 {margin-top: 0; font-size: smaller;}
